@@ -33,10 +33,12 @@ run_config <- function(
     question_structure <- get_question_structure(paths, html_content)
 
     message(
-      "Survey contents saved to:\n",
-      "  ", paths$target_pages, "\n",
+      "Survey content saved to:\n",
+      "  ", paths$target_html, "\n",
       "  ", paths$target_head, "\n",
-      "  ", paths$target_questions
+      "  ", paths$target_pages, "\n",
+      "  ", paths$target_questions, "\n",
+      "  ", paths$target_transl
     )
 
   } else {
@@ -135,12 +137,27 @@ survey_files_need_updating <- function(paths) {
   time_pages <- file.info(paths$target_pages)$mtime
 
   if ((time_qmd > time_pages) || (time_app > time_pages)) { return(TRUE) }
-
+  
+  # Find all YAML files
+  # find_all_yaml_files() defined in ui.R
+  yaml_files <- find_all_yaml_files()
+  
+  # Check if any YAML file is newer than the parsed pages
+  for (yaml_file in yaml_files) {
+    if (fs::file_exists(yaml_file)) {
+      time_yml <- file.info(yaml_file)$mtime
+      if (time_yml > time_pages) { 
+        return(TRUE) 
+      }
+    }
+  }
+  
   # Re-parse if the user provided a 'translations.yml' file which is out of date
   if (fs::file_exists(paths$transl)) {
     time_transl <- file.info(paths$transl)$mtime
     if (time_transl > time_pages) { return(TRUE) }
   }
+  
   return(FALSE)
 }
 
@@ -238,8 +255,6 @@ extract_html_pages <- function(
         stop("No survey pages found. Add divs with either '.sd-page' or '.sd_page' class.")
     }
 
-    message("Using '", class_used, "' class for survey pages.")
-
     pages <- lapply(pages_elements, function(x) {
         page_id <- rvest::html_attr(x, "id")
         question_containers <- rvest::html_elements(x, ".question-container")
@@ -359,18 +374,83 @@ extract_question_structure_html <- function(html_content) {
       # Write options to the question structure
       question_structure[[question_id]]$options <- as.list(options)
 
-      # Extract options for the question (slider)
+    # Extract options for the question (slider)
     } else if (grepl("slider", type)) {
-      options_raw <- question_node |>
-        rvest::html_nodes("input") |>
-        rvest::html_attr("data-swvalues")
-      options <- gsub("\\[|\\]|\\\"", "", options_raw) |>
-        strsplit(",") |>
-        unlist()
-
-      # names(options) <- options # TODO no labels in html for slider
-
-      question_structure[[question_id]]$options <- as.list(options)
+      
+      # Check if this is a numeric slider
+      is_numeric_slider <- length(rvest::html_nodes(question_node, ".js-range-slider:not(.sw-slider-text)")) > 0
+      
+      if (is_numeric_slider) {
+        # Extract min, max, and step attributes from the numeric slider
+        slider_element <- rvest::html_nodes(question_node, ".js-range-slider")
+        
+        min_value <- as.numeric(rvest::html_attr(slider_element, "data-min"))
+        max_value <- as.numeric(rvest::html_attr(slider_element, "data-max"))
+        step_value <- as.numeric(rvest::html_attr(slider_element, "data-step"))
+        
+        # Check if this is a range slider (has data-to attribute)
+        is_range <- !is.na(rvest::html_attr(slider_element, "data-to"))
+        
+        # Get the from and to values for range sliders
+        from_value <- as.numeric(rvest::html_attr(slider_element, "data-from"))
+        to_value <- as.numeric(rvest::html_attr(slider_element, "data-to"))
+        
+        # Default to step=1 if missing or invalid
+        if (is.na(step_value) || step_value <= 0) {
+          step_value <- 1
+        }
+        
+        # Generate sequence
+        numeric_values <- seq(min_value, max_value, by = step_value)
+        
+        # Create a named list with actual numeric values
+        # Start with empty list to ensure the types are preserved
+        named_options <- list()
+        for (val in numeric_values) {
+          named_options[[as.character(val)]] <- val
+        }
+        
+        # Note that this is a range slider in the structure if needed
+        if (is_range) {
+          question_structure[[question_id]]$is_range <- TRUE
+          # Also store the default range values
+          question_structure[[question_id]]$default <- c(from_value, to_value)
+        } else if (!is.na(from_value)) {
+          # For single sliders, store the default value
+          question_structure[[question_id]]$default <- from_value
+        }
+        
+        question_structure[[question_id]]$options <- named_options
+      } else {
+        # For regular text slider
+        options_labels_raw <- question_node |>
+          rvest::html_nodes(".js-range-slider") |>
+          rvest::html_attr("data-swvalues")
+        
+        # Process labels
+        options_labels <- gsub("\\[|\\]|\\\"", "", options_labels_raw) |>
+          strsplit(",") |>
+          unlist()
+        
+        # Convert labels to snake_case for values
+        options_values <- sapply(options_labels, function(label) {
+          # Convert to lowercase
+          value <- tolower(label)
+          # Replace spaces and special characters with underscore
+          value <- gsub("[^a-z0-9]", "_", value)
+          # Replace multiple underscores with a single one
+          value <- gsub("_+", "_", value)
+          # Remove leading and trailing underscores
+          value <- gsub("^_|_$", "", value)
+          return(value)
+        })
+        
+        # Create named options list
+        options <- options_values
+        names(options) <- options_labels
+        
+        question_structure[[question_id]]$options <- as.list(options)
+      }
     }
 
     # Extract the rows and options for the matrix main question
@@ -414,6 +494,7 @@ write_question_structure_yaml <- function(question_structure, file_yaml) {
     'checkbox-group-buttons' = 'mc_multiple_buttons',
     'shiny-input-select' = 'select',
     'js-range-slider sw-slider-text' = 'slider',
+    'js-range-slider' = 'slider_numeric',
     'shiny-date-input form-group shiny-input-container' = 'date',
     'shiny-date-range-input form-group shiny-input-container' = 'daterange'
   )
@@ -433,6 +514,18 @@ write_question_structure_yaml <- function(question_structure, file_yaml) {
     if (question$type == "select") {
       question$options <- question$options[-1]
     }
+
+    # Special handling for numeric slider options to ensure they remain numeric
+    if (question$type == "slider_numeric" && !is.null(question$options)) {
+      # Include all options
+      options_to_include <- seq_along(question$options)
+      
+      # Create a new options list with all elements
+      if (length(options_to_include) > 0) {
+        question$options <- question$options[options_to_include]
+      }
+    }
+    
     return(question)
   })
 
